@@ -249,6 +249,15 @@ class MenuBarController: NSObject {
         )
         submenu.addItem(ignoreDesktopItem)
 
+        // Window Bar Drag - pass through gestures when cursor is over title bar
+        // Allows macOS native three-finger drag to work for window dragging
+        let windowBarDragItem = createAdvancedMenuItem(
+            title: "Window Bar Drag",
+            isOn: preferences.passThroughTitleBar,
+            action: #selector(toggleWindowBarDrag)
+        )
+        submenu.addItem(windowBarDragItem)
+
         submenu.addItem(NSMenuItem.separator())
 
         // Relift during drag - Linux-style text selection
@@ -595,6 +604,18 @@ class MenuBarController: NSObject {
         NotificationCenter.default.post(name: .preferencesChanged, object: preferences)
     }
 
+    @objc func toggleWindowBarDrag() {
+        preferences.passThroughTitleBar.toggle()
+
+        var config = multitouchManager?.configuration ?? GestureConfiguration()
+        config.passThroughTitleBar = preferences.passThroughTitleBar
+        config.titleBarHeight = CGFloat(preferences.titleBarHeight)
+        multitouchManager?.updateConfiguration(config)
+
+        buildMenu()
+        NotificationCenter.default.post(name: .preferencesChanged, object: preferences)
+    }
+
     @objc func toggleAllowReliftDuringDrag() {
         preferences.allowReliftDuringDrag.toggle()
 
@@ -608,6 +629,26 @@ class MenuBarController: NSObject {
     
     @objc func forceReleaseStuckDrag() {
         multitouchManager?.forceReleaseStuckDrag()
+        
+        // Provide visual feedback that the action was triggered
+        flashStatusBarIcon()
+    }
+    
+    /// Flash the status bar icon to provide visual feedback for actions
+    /// Uses alpha animation consistent with updateStatusIcon pattern
+    private func flashStatusBarIcon() {
+        guard let button = statusItem?.button else { return }
+        
+        // Use alpha animation for visual feedback (consistent with updateStatusIcon)
+        NSAnimationContext.runAnimationGroup { context in
+            context.duration = 0.1
+            button.animator().alphaValue = 0.3
+        } completionHandler: {
+            NSAnimationContext.runAnimationGroup { context in
+                context.duration = 0.1
+                button.animator().alphaValue = 1.0
+            }
+        }
     }
 
     @objc func toggleLaunchAtLogin() {
